[Setup]
#define AppName "productName"
#define DevDir "yourCompanyName"
AppName={#AppName}
AppVersion=1.0.0

DefaultDirName={pf}\{#DevDir}\{#AppName}
DefaultGroupName={#AppName}
Compression=lzma2
SolidCompression=yes
OutputDir=.\installerbuild
ArchitecturesInstallIn64BitMode=x64
OutputBaseFilename={#AppName} Installer 1.0.0
LicenseFile=".\installerAssets\EULA.txt"
PrivilegesRequired=admin
WizardSmallImageFile=".\installerAssets\Logo55x58.bmp"
WizardImageFile=".\installerAssets\Logo164x314.bmp"
SetupIconFile=".\installerAssets\icon.ico"
SetupLogging=yes
ChangesAssociations=no

[Types]
Name: "full"; Description: "Full installation"
Name: "custom"; Description: "Custom installation"; Flags: iscustom

[Dirs]
Name: "{app}\"; Permissions: users-modify powerusers-modify admins-modify system-modify


Name: "{userappdata}\{yourCompanyName}\{productName}"; Permissions: users-modify powerusers-modify admins-modify system-modify

[Components]
Name: "vst2_64"; Description: "{#AppName} 64-bit VSTi Plugin"; Types: full custom; Check: Is64BitInstallMode;
Name: "samples"; Description: "{#AppName} Sample Set"; Types: full custom;    

[Files]

; VST
; Install x64 VST plugin

Source: "Binaries\Compiled\VST\{#AppName} x64.dll"; DestDir: "{code:GetVST2Dir_64}\{#DevDir}"; Flags: ignoreversion; Components: vst2_64; Check: Is64BitInstallMode

; SAMPLE FILE
; Add every SampleMap of the instrument -- Must be located in the Project Folder -- Delete or comment these lines if you're installing a solo-plugin
Source: "sampleMap1.ch1"; DestDir: "{code:GetSamplesDir}"; Flags: ignoreversion; Components: samples;
Source: "sampleMap2.ch1"; DestDir: "{code:GetSamplesDir}"; Flags: ignoreversion; Components: samples; 

[Icons]
Name: "{group}\{#AppName}"; Filename: "{app}\{#AppName} x64.exe"; Check: Is64BitInstallMode; IconFilename: "C:\{location}\icon.ico"
Name: "{group}\Uninstall {#AppName}"; Filename: "{app}\unins000.exe"
Name: "{group}\productName_Manual"; Filename: "{app}\productName_Manual.pdf"

[Code]
var
  OkToCopyLog : Boolean;
  VST2DirPage_64: TInputDirWizardPage;
  SamplesDirPage: TInputDirWizardPage;

procedure InitializeWizard;

begin

  if IsWin64 then begin
    VST2DirPage_64 := CreateInputDirPage(wpSelectDir,
    'Confirm 64-Bit VST2 Plugin Directory', '',
    'Select the folder in which setup should install the 64-bit VST2 Plugin, then click Next.',
    False, '');
    VST2DirPage_64.Add('');
    VST2DirPage_64.Values[0] := ExpandConstant('{reg:HKLM\SOFTWARE\VST,VSTPluginsPath|{pf}\Steinberg\VSTPlugins}\');
  end 
end;

function GetVST2Dir_64(Param: String): String;
begin
  Result := VST2DirPage_64.Values[0]
end;

function GetSamplesDir(Param: String): String;
begin
  Result := SamplesDirPage.Values[0]
end;

procedure CurStepChanged(CurStep: TSetupStep);
begin
  SaveStringToFile(ExpandConstant('{userappdata}\{yourCompanyName}\{productName}\LinkWindows'), SamplesDirPage.Values[0], False)    ; //Creates the 'LinkWindows' file where the Sample Location is specified
  if CurStep = ssDone then
    OkToCopyLog := True;
end;

procedure DeinitializeSetup();
begin
  if OkToCopyLog then
    FileCopy (ExpandConstant ('{log}'), ExpandConstant ('{app}\InstallationLogFile.log'), FALSE);
  RestartReplace (ExpandConstant ('{log}'), '');
end;

[UninstallDelete]
Type: files; Name: "{app}\InstallationLogFile.log"
Type: filesandordirs; Name: "{userappdata}\{yourCompanyName}\{productName}"

